@@ -3,7 +3,7 @@
 #
 #  (C) Paul Evans, 2023 -- leonerd@leonerd.org.uk
 
-package Object::Pad::FieldAttr::Checked 0.05;
+package Object::Pad::FieldAttr::Checked 0.06;
 
 use v5.14;
 use warnings;
@@ -83,8 +83,9 @@ supported.
 
 At compiletime, the string given by I<EXPRESSION> is C<eval()>'ed in scalar
 context, and its result is stored as part of the field's definition. The
-expression must yield either an object reference, or a string containing the
-name of a package. In either case, a method called C<check> must exist on it.
+expression must yield either an object reference, a code reference, or a
+string containing the name of a package. In the case of an object or package,
+a method called C<check> must exist on it.
 
 During the string C<eval()> of the expression, the C<strict 'subs'> pragma is
 specifically disabled, allowing a bareword to be used as the name of a
@@ -101,7 +102,11 @@ value for  the field is passed as an argument. If the method returns true, the
 assignment is allowed. If false, it is rejected with an exception and the
 field itself remains unmodified.
 
-   $ok = $checker->check( $value );
+   $ok = $checkerobj->check( $value );  # if an object
+
+   $ok = $checkersub->( $value );       # if a code reference
+
+   $ok = $checkerpkg->check( $value );  # if a package name
 
 (For performance reasons, the C<check> method is actually resolved into a
 function at compiletime when the C<:Checked> attribute is applied, and this
